clear
close all
clc

% Parameters
%   Discount factor
P.beta = 0.95;
%   CRRA
P.sigma = 2;
%   Probabilities for preference shock
P.p = [.5,.5];
%   Interest Rate
P.R = 1;
%   IES
iesl = .01:.01:.99;
iesh = 1.01:.01:2;
iess = [iesl,iesh];
nies = numel(iess);
niesl = numel(iesl);
%   Preference shock tail
atails = [.02,.05];
natails = numel(atails);
%   fsolve options
options = optimset('Display','off','TolX',1e-10,'TolFun',1e-10);
x0 = .5;

c0_per = zeros(nies,2,natails);
for imod = 1:2
    if imod == 1
        % BB
        U1 = @(c0,P) P.a*(1-P.beta)*(P.R*(1 - c0))^((1-P.sigma)/P.theta) + P.beta;
        EU1 = @(c0,P) P.p*U1(c0,P).^P.theta;
        EE = @(c0,P) 1 - P.p*(P.R*P.beta*P.a*(P.R*(1 - c0)/c0)^((1-P.sigma)/P.theta-1).*(...
            U1(c0,P).^P.theta/EU1(c0,P)).^(1-1/P.theta));
    elseif imod == 2
        % DRT
        U1 = @(c0,P) (1-P.beta*P.a)*(P.R*(1 - c0))^((1-P.sigma)/P.theta) + P.beta*P.a;
        EU1 = @(c0,P) P.p*U1(c0,P).^P.theta;
        EE = @(c0,P) 1 - P.p*(P.R*P.beta*((1-P.beta*P.a)/(1-P.beta)).* ...
            (P.R*(1 - c0)/c0)^((1-P.sigma)/P.theta-1).*(...
            U1(c0,P).^P.theta/EU1(c0,P)).^(1-1/P.theta));
    end

    % No Uncertainty
    P.a = [1,1]';
    c0_b = zeros(nies,1);
    for iies = 1:nies
        P.theta = (1-P.sigma)/(1 - 1/iess(iies));
        c0_b(iies) = fsolve(EE,x0,options,P);
    end

    % Uncertainty
    for iatail = 1:natails
        if imod == 1
            P.a = 1 + atails(iatail)*[1,-1]';
        elseif imod == 2
            P.a = 1 + atails(iatail)*[1,-1]'.*(1-P.beta);
        end
        c0 = zeros(nies,1);
        for iies = 1:nies
            P.theta = (1-P.sigma)/(1 - 1/iess(iies));
            c0(iies) = fsolve(EE,x0,options,P);
        end

        % Percent change
        c0_per(:,imod,iatail) = 100*(c0./c0_b-1);
    end
end

%% Plot figures
close all
saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 2.5];
figinnerbox = [.11 .175 .86 .8];
plotdim = [1,2];
fontsize = 10;
colors = {[0 0 0] [0 0 1] [1 0 0] [.5 0 .5]}; 
type_line = {'-','--','-','-'};

ylims = [.02,.2];

iatail = 1;
figure(iatail); hold on; box on; grid on;
set(gcf,'Position',figbox);
set(gca,'Position',figinnerbox);
for imod = 1:2
    if imod == 1
        plot(iesl,c0_per(1:niesl,imod,iatail),...
            type_line{imod},'color',colors{imod})
        p1(imod) = plot(iesh,c0_per(niesl+1:end,imod,iatail),...
            type_line{imod},'color',colors{imod});
    elseif imod == 2
        p1(imod) = plot(iess,c0_per(:,imod,iatail),...
            type_line{imod},'color',colors{imod});
    end
end
plot([1,1],ylims(iatail)*[-1,1],'k--');
set(gca,'ytick',linspace(-ylims(iatail),ylims(iatail),5),'ylim',ylims(iatail)*[-1,1]);
plot(0.95,c0_per(iess==0.95,1,iatail),'.r','MarkerSize',15)
ylabel('Consumption (\%)','fontsize',fontsize)
xlabel('IES ($\psi$)','fontsize',fontsize)
if iatail == 1
    legstr = {'BB Preferences','Alternative Preferences'};
    leg1 = legend(p1,legstr,'Orientation','horizontal',...
        'Location','NorthWest',...
        'Orientation','vertical',...
        'FontSize',fontsize,'interpreter','latex');
end

% Save figure
if strcmp(saving,'on')
    savename = ['DRT Figures\fig_intuition' num2str(iatail)];
    print(iatail,'-depsc2','-painters',[savename '.eps'])
    saveas(iatail,[savename '.fig'])
end