clear
close all
clc

% Parameters
%   Discount factor
P.beta = 0.95;
%   CRRA
P.sigma = 2;
%   Probabilities for preference shock
P.p = [.5,.5];
%   Interest Rate
P.R = 1;
%   IES
iesl = .01:.005:.999;
iesh = 1.001:.005:2;
iess = [iesl,iesh];
nies = numel(iess);
niesl = numel(iesl);
%   fsolve options
options = optimset('Display','off','TolX',1e-10,'TolFun',1e-10);
x0 = .5;

for imod = 1:2
    if imod == 1
        % BB
        U1      = @(c0,P) P.a*(1-P.beta)*(P.R*(1 - c0))^((1-P.sigma)/P.theta) + P.beta;
        EU1     = @(c0,P) P.p*U1(c0,P).^P.theta;
        
        U1adj   = @(c0,P) P.a*(1-P.beta)*(P.R*P.beta/(1+P.beta))^((1-P.sigma)/P.theta) + P.beta;
        EU1adj  = @(c0,P) P.p*U1adj(c0,P).^P.theta;
        
        EE = @(c0,P) 1 - P.p*(P.R*P.beta*P.a*(P.R*(1 - c0)/c0)^((1-P.sigma)/P.theta-1).*(U1(c0,P).^P.theta/EU1(c0,P)).^(1-1/P.theta));
        %adjusted
        EEx = @(c0,P) 1 - P.p*(P.R*P.beta*P.a*(P.R*(1 - c0)/c0)^((1-P.sigma)/P.theta-1).*(U1adj(c0,P).^P.theta/EU1adj(c0,P)).^(1-1/P.theta));
    elseif imod == 2
        % DRT
        U1      = @(c0,P) (1-P.beta*P.a)*(P.R*(1 - c0))^((1-P.sigma)/P.theta) + P.beta*P.a;
        EU1     = @(c0,P) P.p*U1(c0,P).^P.theta;
        
        U1adj   = @(c0,P) (1-P.beta*P.a)*(P.R*P.beta/(1+P.beta))^((1-P.sigma)/P.theta) + P.beta*P.a;
        EU1adj  = @(c0,P) P.p*U1adj(c0,P).^P.theta;
        
        EE = @(c0,P) 1 - P.p*(P.R*P.beta*((1-P.beta*P.a)/(1-P.beta)).* (P.R*(1 - c0)/c0)^((1-P.sigma)/P.theta-1).*(U1(c0,P).^P.theta/EU1(c0,P)).^(1-1/P.theta));
        %adjusted
        EEx = @(c0,P) 1 - P.p*(P.R*P.beta*((1-P.beta*P.a)/(1-P.beta)).* (P.R*(1 - c0)/c0)^((1-P.sigma)/P.theta-1).*(U1adj(c0,P).^P.theta/EU1adj(c0,P)).^(1-1/P.theta));
        
    end
 
    % No Uncertainty
    P.a = [1,1]';
    c0_b = zeros(nies,1);
    for iies = 1:nies
        P.theta = (1-P.sigma)/(1 - 1/iess(iies));
        P.rho = 1/iess(iies);
        P.psi = iess(iies);
        c0_b(iies) = fsolve(EE,x0,options,P);
    end
    P.delta = .02;
    % Uncertainty
    if imod == 1
        P.a = [1+P.delta,1-P.delta]';
    elseif imod == 2
        P.a = 1 + [P.delta,-P.delta]'.*(1-P.beta);
    end
    c0 = zeros(nies,1);
    for iies = 1:nies
        P.theta = (1-P.sigma)/(1 - 1/iess(iies));
        P.rho = 1/iess(iies);
        P.psi = iess(iies);
        c0(iies) = fsolve(EE,x0,options,P);
        c0x(iies) = fsolve(EEx,x0,options,P);
    end
    
    for iexact = 1:2
        for iies = 1:nies
            ies = iess(iies);
            if iexact == 1
                c_1 = P.R.*(1-c0(iies));
            elseif iexact == 2
                c_1 = P.R.*P.beta/(1+P.beta);
            end
            if imod == 1
                v_0             = (P.a.*(1-P.beta).*c_1.^(1-1./ies) + P.beta).^(1./(1-1./ies));
                w_0             = v_0.^(1./ies-P.sigma);
                t_0             = (1./ies-P.sigma)./(1-P.sigma);
                ev_0            = P.p*v_0;
                ew_0            = P.p*w_0;
                ewx_0           = (P.p*(w_0.^(1./t_0))).^t_0;
                covav_0         = P.p*((P.a-P.p*P.a).*(v_0-ev_0));
                covaw_0         = P.p*((P.a-P.p*P.a).*(w_0-ew_0));
                woe_0           = (ew_0./ewx_0);
                coe_0           = (1+covaw_0./ew_0);
            elseif imod == 2
                v_0             = ((1-P.a.*P.beta).*c_1.^(1-1./ies) + P.a.*P.beta).^(1./(1-1./ies));
                w_0             = v_0.^(1./ies-P.sigma);
                t_0             = (1./ies-P.sigma)./(1-P.sigma);
                ev_0            = P.p*v_0;
                ew_0            = P.p*w_0;
                ewx_0           = (P.p*(w_0.^(1./t_0))).^t_0;
                covav_0         = P.p*(((1-P.a.*P.beta)/(1-P.beta)-1).*(v_0-ev_0));
                covaw_0         = P.p*(((1-P.a.*P.beta)/(1-P.beta)-1).*(w_0-ew_0));
                woe_0           = (ew_0./ewx_0);
                coe_0           = (1+covaw_0./ew_0);
            end

            plotme(iies,imod,1,iexact) = woe_0;
            plotme(iies,imod,2,iexact) = coe_0;
            plotme(iies,imod,3,iexact) = covav_0;
            plotme(iies,imod,4,iexact) = covaw_0;
        end
    end
end

%% Plot figures
saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 3.75];
plotdim = [2,2];
pad.topmarg = .15;
pad.leftmarg = .08;
pad.vspace = .175;
pad.hspace = .12;
pad.rightmarg = .03;
pad.botmarg = .12;
fontsize = 10;
colors = {[0 0 0] [0 0 1] [1 0 0] [.5 0 .5]}; 
type_line = {'-','--','-','-'};

titlestr = {...
    'Risk Aversion Term',...
    'Covariance Term',...
    '$\textrm{cov}_0(\tilde{a}_1,V^{j}_1)$',...
    '$\textrm{cov}_0(\tilde{a}_1,W^{j}_1)$'};
axes = {[0,2,.9996,1.0004],...
        [0,2,.9996,1.0004],...
        [0,2,-.0002,.0002],...
        [0,2,-.0002,.0002]};

figure(1)
set(gcf,'Position',figbox);
iexact = 2; % approximate solution
for isubplot = 1:4
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),isubplot);
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),isubplot,'Position',[left bottom width height]); grid on; hold on; box on;
    
    for imod = 1:2
        if imod == 1
            plot(iess(iess<1),plotme(iess<1,imod,isubplot,iexact),...
                type_line{imod},'color',colors{imod});
            p1(imod) = plot(iess(iess>1),plotme(iess>1,imod,isubplot,iexact),...
                type_line{imod},'color',colors{imod});
        elseif imod == 2
            p1(imod) = plot(iess,plotme(:,imod,isubplot,iexact),...
                type_line{imod},'color',colors{imod});
        end
    end
    plot([1,1],axes{isubplot}(3:4),'k--');
    title(titlestr{isubplot})
    axis(axes{isubplot})
    xlabel('IES ($\psi$)','fontsize',fontsize)
end
legstr = {'BB Preferences','Alternative Preferences'};
leg1 = legend(p1,legstr,'Orientation','horizontal',...
    'Position',[.25 1-pad.topmarg+.03 0.5 pad.topmarg],...
    'FontSize',fontsize,'interpreter','latex');

% Save figure
if strcmp(saving,'on')
    savename = 'DRT Figures\fig_intuition_decomp';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end

%%
disp('BB prefs: % change c_1 given 1% increase in a_1')
psi = .99;
theta = (1-P.sigma)/(1-1/psi);
a1 = 1;
c1 = .5;
v1bb = (a1*(1-P.beta)*c1^((1-P.sigma)/theta)+P.beta)^(theta/(1-P.sigma));
a1new = 1.01;
c1new = ((v1bb^((1-P.sigma)/theta)-P.beta)/(a1new*(1-P.beta)))^(theta/(1-P.sigma));
c1per = 100*(c1new/c1-1)