clear
close all
clc

% Parameters
%   Discount factor
P.beta = 0.95;
%   Probabilities for preference shock
P.p = [.5,.5];
%   Interest Rate
P.R = 1;
%   IES
iesl = .01:.01:.99;
iesh = 1.01:.01:2;
iess = [iesl,iesh];
nies = numel(iess);
niesl = numel(iesl);
%   CRRA parameters
sigmas = [2,5];
%   Preference shock tail
atails = [.02,.05];
natails = numel(atails);
%   fsolve options
options = optimset('Display','off','TolX',1e-10,'TolFun',1e-10);
x0 = .5;

c0_per = zeros(nies,2,natails,2);
for imod = 1:2
    if imod == 1
        % BB
        U1 = @(c0,P) P.a*(1-P.beta)*(P.R*(1 - c0))^((1-P.sigma)/P.theta) + P.beta;
        EU1 = @(c0,P) P.p*U1(c0,P).^P.theta;
        EE = @(c0,P) 1 - P.p*(P.R*P.beta*P.a*(P.R*(1 - c0)/c0)^((1-P.sigma)/P.theta-1).*(...
            U1(c0,P).^P.theta/EU1(c0,P)).^(1-1/P.theta));
    elseif imod == 2
        % DRT
        U1 = @(c0,P) (1-P.beta*P.a)*(P.R*(1 - c0))^((1-P.sigma)/P.theta) + P.beta*P.a;
        EU1 = @(c0,P) P.p*U1(c0,P).^P.theta;
        EE = @(c0,P) 1 - P.p*(P.R*P.beta*((1-P.beta*P.a)/(1-P.beta)).* ...
            (P.R*(1 - c0)/c0)^((1-P.sigma)/P.theta-1).*(...
            U1(c0,P).^P.theta/EU1(c0,P)).^(1-1/P.theta));
    end

    % Higher CRRA
    isubplot = 1;
    iatail = 1;
    for isigma = 1:numel(sigmas)
        P.sigma = sigmas(isigma);
        %   No Uncertainty
        P.a = [1,1]';
        c0_b = zeros(nies,1);
        for iies = 1:nies
            P.theta = (1-P.sigma)/(1 - 1/iess(iies));
            c0_b(iies) = fsolve(EE,x0,options,P);
        end
        %   Uncertainty
        if imod == 1
            P.a = 1 + atails(iatail)*[1,-1]';
        elseif imod == 2
            P.a = 1 + atails(iatail)*[1,-1]'.*(1-P.beta);
        end
        c0 = zeros(nies,1);
        for iies = 1:nies
            P.theta = (1-P.sigma)/(1 - 1/iess(iies));
            c0(iies) = fsolve(EE,x0,options,P);
        end

        % Percent change
        c0_per(:,imod,isigma,isubplot) = 100*(c0./c0_b-1);
    end

    % Higher pref. shock variance
    isubplot = 2;
    P.sigma = sigmas(1);
    %   No Uncertainty
    P.a = [1,1]';
    c0_b = zeros(nies,1);
    for iies = 1:nies
        P.theta = (1-P.sigma)/(1 - 1/iess(iies));
        c0_b(iies) = fsolve(EE,x0,options,P);
    end
    %   Uncertainty
    for iatail = 1:natails
        if imod == 1
            P.a = 1 + atails(iatail)*[1,-1]';
        elseif imod == 2
            P.a = 1 + atails(iatail)*[1,-1]'.*(1-P.beta);
        end
        c0 = zeros(nies,1);
        for iies = 1:nies
            P.theta = (1-P.sigma)/(1 - 1/iess(iies));
            c0(iies) = fsolve(EE,x0,options,P);
        end

        % Percent change
        c0_per(:,imod,iatail,isubplot) = 100*(c0./c0_b-1);
    end
end

%% Plot figures
saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 2.45];
plotdim = [1,2];
pad.topmarg = .1;
pad.leftmarg = .09;
pad.vspace = .175;
pad.hspace = .115;
pad.rightmarg = .015;
pad.botmarg = .175;
fontsize = 10;
colors = {[0 0 0],[.5 .5 .5],[0 0 1],[.5 .5 1],}; 
linetypes = {'-','-.','--','-.'};

ylims = [.04,.2];
titlestr = {'Risk Aversion ($\sigma$)','Uncertainty ($\Delta$)'};
legstr{1} = {  'BB ($\sigma = 2$)','BB ($\sigma = 5$)',...
            'ALT ($\sigma = 2$)','ALT ($\sigma = 5$)'};
legstr{2} = {  'BB ($\Delta = 0.02$)','BB ($\Delta = 0.05$)',...
            'ALT ($\Delta = 0.02$)','ALT ($\Delta = 0.05$)'};

figure(1)
set(gcf,'Position',figbox);
for isubplot = 1:2
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),isubplot);
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),isubplot,'Position',[left bottom width height]); grid on; hold on; box on;
     
    for ispec = 1:2
        for imod = 1:2
            iline = 2*(imod-1) + ispec;
            if imod == 1
                plot(iesl,c0_per(1:niesl,imod,ispec,isubplot),...
                    linetypes{iline},'color',colors{iline})
                p1(iline) = plot(iesh,c0_per(niesl+1:end,imod,ispec,isubplot),...
                    linetypes{iline},'color',colors{iline});
            elseif imod == 2
                p1(iline) = plot(iess,c0_per(:,imod,ispec,isubplot),...
                    linetypes{iline},'color',colors{iline});
            end
        end
        plot(0.95,c0_per(iess==0.95,1,ispec,isubplot),'.r','MarkerSize',15);
    end 
    set(gca,'ylim',[-.12,.12],'ytick',-.12:.04:.12)
    plot([1,1],[-.12,.12],'k--')
    title(titlestr{isubplot})
    ylabel('Consumption (\%)','fontsize',fontsize)
    xlabel('IES ($\psi$)','fontsize',fontsize)
    
    %   Add Legend
    [leg1,hObj] = legend(p1,legstr{isubplot},'Orientation','vertical',...
        'Location','NorthWest',...
        'FontSize',6,'interpreter','latex');
end

% Save figure
if strcmp(saving,'on')
    savename = 'DRT Figures\fig_intuition_robust';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end