clear; close all; clc

figonly = 0;

% model: bb or drt
modstrs = {'bb','drt'};

% BB calibration
phip_bb = 100;
phik_bb = 2.0901;
sigma_bb = 80;
ies_bb = 0.95;

% IES values
iess = sort([   linspace(.01,.75,10),...
                linspace(.76,.90,10),...
                linspace(.91,.9994,15),...
                linspace(1.0005,1.09,15),...
                linspace(1.10,1.5,10),...
                linspace(1.51,2,10),...
                .95]);
nies = numel(iess);

if ~figonly
    addpath('C:\dynare\4.4.3\matlab')
    file_loc = cd;

    cd('BaselineModel/StickyvsFlexiblePrices')
    
    % Dynare pre-processor to generate m-file
    phip_m = phip_bb;
    phik_m = phik_bb;
    sigma_m = sigma_bb;
    ies_m = ies_bb;
    for imod = 1:2
        modstr = modstrs{imod};
        if strcmp(modstr,'bb')
            save('ies.mat','ies_m')
            delete bbeffectivedemand.m
            dynare bbeffectivedemand.mod noclearall
        elseif strcmp(modstr,'drt')
            save('param.mat','phip_m','phik_m','sigma_m','ies_m')
            delete DRT_bbeffectivedemand.m
            dynare DRT_bbeffectivedemand.mod noclearall
        end

        y_impact_avol = zeros(nies,1);
        c_impact_avol = zeros(nies,1);
        i_impact_avol = zeros(nies,1);
        y_impact_alev = zeros(nies,1);
        c_impact_alev = zeros(nies,1);
        i_impact_alev = zeros(nies,1);
        for iies = 1:nies
            ies_m = iess(iies);
            if strcmp(modstr,'bb')
                save('ies.mat','ies_m')
                bbeffectivedemand;
            elseif strcmp(modstr,'drt')
                ies_m = iess(iies);
                save('param.mat','phip_m','phik_m','sigma_m','ies_m')
                DRT_bbeffectivedemand;
            end
                 
            y_impact_avol(iies) = 100*y_evola(1)./y_sss;
            c_impact_avol(iies) = 100*c_evola(1)./c_sss;  
            i_impact_avol(iies) = 100*inv_evola(1)./inv_sss;  
            y_impact_alev(iies) = 100*y_ea(1)./y_sss;
            c_impact_alev(iies) = 100*c_ea(1)./c_sss;  
            i_impact_alev(iies) = 100*inv_ea(1)./inv_sss;
        end
    
        if strcmp(modstr,'bb')
            impact(:,:,1) = [y_impact_avol,c_impact_avol,i_impact_avol,y_impact_alev,c_impact_alev,i_impact_alev];
        elseif strcmp(modstr,'drt')
            impact(:,:,2) = [y_impact_avol,c_impact_avol,i_impact_avol,-y_impact_alev,-c_impact_alev,-i_impact_alev];
        end
    end
    
    cd(file_loc);
    
    names1 = {'Output','Consumption','Investment','Output','Consumption','Investment'};
    names2 = {'Volatility','Volatility','Volatility','Level','Level','Level'};
    names3 = {'Discount','Discount','Discount','Discount','Discount','Discount'};

    save('temp_combined.mat')
else
    load('temp_combined.mat')
end

%% Plot figures

saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 4.75];
plotdim = [2,3];
pad.topmarg = .11;
pad.leftmarg = .09;
pad.vspace = .135;
pad.hspace = .1;
pad.rightmarg = .02;
pad.botmarg = .1;
markersize = 3;
markergrid = linspace(min(iess),max(iess),9);
fontsize = 10;
colors = {[0 0 0] [0 0 1] [1 0 0] [.5 0 .5]}; 
type_line = {'-','--','-','-'};
type_mark = {'.','.','o','^'};
type_leg = {'-','--','-o','-^'};
nticks = 8;

axes = [0 2 -.15 .15;
        0 2 -.15 .15;
        0 2 -.15 .15;
        0 2 -.1 -0.02;
        0 2 0 .3;
        0 2 -1 -.199];

titlestrs = {'Volatility Shock','Volatility Shock','Volatility Shock','Level Shock','Level Shock','Level Shock'};
reorder = [4,5,6,1,2,3];

figure(1);
set(gcf,'Position',figbox);
for j = 1:6
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),reorder(j));
    ivar = row; ishock = col;
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),reorder(j),'Position',[left bottom width height]); grid on; hold on; box on;
    
    % Plot
    for imod = 1:2
        modstr = modstrs{imod};
        if strcmp(modstr,'bb')
            plot(iess(iess<1),impact(iess<1,j,imod),type_leg{imod},'color',colors{imod})
            p1(imod) = plot(iess(iess>1),impact(iess>1,j,imod),type_leg{imod},'color',colors{imod});
        elseif strcmp(modstr,'drt')
            p1(imod) = plot(iess,impact(:,j,imod),type_leg{imod},'color',colors{imod});
        end
    end
    plot([1,1],axes(j,3:4),'k--') 
    plot(0.95,impact(iess==0.95,j,1),'.r','MarkerSize',15)
    xlabel('IES ($\psi$)','fontsize',fontsize)
    ylabel([names1{j} ' ($\%$)'],'fontsize',fontsize)
    title(titlestrs{j},'fontsize',fontsize);
    axis(axes(j,:))
    set(gca,'xtick',0:.5:2)
    if j < 4
        set(gca,'ytick',linspace(axes(j,3),axes(j,4),7))
    end
end

% Add Legend
legstr = {'BB Preferences','Alternative Preferences'};
leg1 = legend(p1,legstr,'Orientation','horizontal',...
    'Position',[.25 1-pad.topmarg+.03 0.5 pad.topmarg],...
    'FontSize',fontsize,'interpreter','latex');

if strcmp(saving,'on')
    savename = 'DRT Figures/fig_combined_pref';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end