clear; close all; clc

figonly = 0;

% model: bb or drt
modstr = 'drt';

% BB calibration
phip_bb = 100;
phik_bb = 2.0901;
sigma_bb = 80;
ies_bb = 0.95;

% Alternative Calibrations
phips = [0,100,200,1000];
phiks = [0,2.0901,4,16];
sigmas = [2,80,160,1000];
iess = sort([   linspace(.01,.75,10),...
                linspace(.76,.90,10),...
                linspace(.91,.9994,15),...
                linspace(1.0005,1.09,15),...
                linspace(1.10,1.5,10),...
                linspace(1.51,2,10),...
                .95]);
nphip = numel(phips);
nphik = numel(phiks);
nsigma = numel(sigmas);
nies = numel(iess);

if ~figonly
    addpath('C:\dynare\4.4.3\matlab')
    file_loc = cd;

    cd('BaselineModel/StickyvsFlexiblePrices')
    
    % Dynare pre-processor to generate m-file
    phip_m = phip_bb;
    phik_m = phik_bb;
    sigma_m = sigma_bb;
    ies_m = ies_bb;
    if strcmp(modstr,'bb')
        save('ies.mat','ies_m')
        delete bbeffectivedemand.m
        dynare bbeffectivedemand.mod noclearall
    elseif strcmp(modstr,'drt')
        save('param.mat','phip_m','phik_m','sigma_m','ies_m')
        delete DRT_bbeffectivedemand.m
        dynare DRT_bbeffectivedemand.mod noclearall
    end

    if strcmp(modstr,'bb')
        y_impact_avol = zeros(nies,1);
        c_impact_avol = zeros(nies,1);
        i_impact_avol = zeros(nies,1);
        y_impact_alev = zeros(nies,1);
        c_impact_alev = zeros(nies,1);
        i_impact_alev = zeros(nies,1);
        for iies = 1:nies
            ies_m = iess(iies);

            save('ies.mat','ies_m')
            bbeffectivedemand;

            y_impact_avol(iies) = 100*y_evola(1)./y_sss;
            c_impact_avol(iies) = 100*c_evola(1)./c_sss;  
            i_impact_avol(iies) = 100*inv_evola(1)./inv_sss;  
            y_impact_alev(iies) = 100*y_ea(1)./y_sss;
            c_impact_alev(iies) = 100*c_ea(1)./c_sss;  
            i_impact_alev(iies) = 100*inv_ea(1)./inv_sss;
        end
    end

    if strcmp(modstr,'drt')
        y_impact_vol = zeros(nies,nphip,nphik,nsigma);
        c_impact_vol = zeros(nies,nphip,nphik,nsigma);
        i_impact_vol = zeros(nies,nphip,nphik,nsigma);
        y_impact_lev = zeros(nies,nphip,nphik,nsigma);
        c_impact_lev = zeros(nies,nphip,nphik,nsigma);
        i_impact_lev = zeros(nies,nphip,nphik,nsigma);
        
        % Alternative price adjustment costs
        iphik = find(phiks == phik_bb);
        isigma = find(sigmas == sigma_bb);
        for iphip = 1:nphip
            for iies = 1:nies
                phip_m = phips(iphip);
                phik_m = phiks(iphik);
                sigma_m = sigmas(isigma);
                ies_m = iess(iies);

                save('param.mat','phip_m','phik_m','sigma_m','ies_m')
                DRT_bbeffectivedemand;

                y_impact_vol(iies,iphip,iphik,isigma) = 100*y_evola(1)./y_sss;
                c_impact_vol(iies,iphip,iphik,isigma) = 100*c_evola(1)./c_sss;  
                i_impact_vol(iies,iphip,iphik,isigma) = 100*inv_evola(1)./inv_sss;  
                y_impact_lev(iies,iphip,iphik,isigma) = 100*y_ea(1)./y_sss;
                c_impact_lev(iies,iphip,iphik,isigma) = 100*c_ea(1)./c_sss;  
                i_impact_lev(iies,iphip,iphik,isigma) = 100*inv_ea(1)./inv_sss;
            end
        end
        
        % Alternative capital adjustment costs
        iphip = find(phips == phip_bb);
        isigma = find(sigmas == sigma_bb);
        for iphik = setdiff(1:nphik,find(phiks == phik_bb))
            for iies = 1:nies
                phip_m = phips(iphip);
                phik_m = phiks(iphik);
                sigma_m = sigmas(isigma);
                ies_m = iess(iies);

                save('param.mat','phip_m','phik_m','sigma_m','ies_m')
                DRT_bbeffectivedemand;

                y_impact_vol(iies,iphip,iphik,isigma) = 100*y_evola(1)./y_sss;
                c_impact_vol(iies,iphip,iphik,isigma) = 100*c_evola(1)./c_sss;  
                i_impact_vol(iies,iphip,iphik,isigma) = 100*inv_evola(1)./inv_sss;  
                y_impact_lev(iies,iphip,iphik,isigma) = 100*y_ea(1)./y_sss;
                c_impact_lev(iies,iphip,iphik,isigma) = 100*c_ea(1)./c_sss;  
                i_impact_lev(iies,iphip,iphik,isigma) = 100*inv_ea(1)./inv_sss;  
            end
        end
        
        % Alternative risk aversions
        iphip = find(phips == phip_bb);
        iphik = find(phiks == phik_bb);
        for isigma = setdiff(1:nsigma,find(sigmas == sigma_bb))
            for iies = 1:nies
                phip_m = phips(iphip);
                phik_m = phiks(iphik);
                sigma_m = sigmas(isigma);
                ies_m = iess(iies);

                save('param.mat','phip_m','phik_m','sigma_m','ies_m')
                DRT_bbeffectivedemand;

                y_impact_vol(iies,iphip,iphik,isigma) = 100*y_evola(1)./y_sss;
                c_impact_vol(iies,iphip,iphik,isigma) = 100*c_evola(1)./c_sss;  
                i_impact_vol(iies,iphip,iphik,isigma) = 100*inv_evola(1)./inv_sss;  
                y_impact_lev(iies,iphip,iphik,isigma) = 100*y_ea(1)./y_sss;
                c_impact_lev(iies,iphip,iphik,isigma) = 100*c_ea(1)./c_sss;  
                i_impact_lev(iies,iphip,iphik,isigma) = 100*inv_ea(1)./inv_sss;  
            end
        end
    end
    
    cd(file_loc);
    
    if strcmp(modstr,'bb')
        impact = [y_impact_avol,c_impact_avol,i_impact_avol,y_impact_alev,c_impact_alev,i_impact_alev];
    elseif strcmp(modstr,'drt')
        impact = cat(5,y_impact_vol,c_impact_vol,i_impact_vol,-y_impact_lev,-c_impact_lev,-i_impact_lev);
    end
    
    names1 = {'Output','Consumption','Investment','Output','Consumption','Investment'};
    names2 = {'Volatility','Volatility','Volatility','Level','Level','Level'};
    names3 = {'Discount','Discount','Discount','Discount','Discount','Discount'};

    save(['temp_' modstr '.mat'])
else
    load(['temp_' modstr '.mat'])
end

%% Plot figures

saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 4];
plotdim = [2,3];
pad.topmarg = .06;
pad.leftmarg = .1;
pad.vspace = .175;
pad.hspace = .1;
pad.rightmarg = .02;
pad.botmarg = .1;
markersize = 3;
markergrid = linspace(min(iess),max(iess),9);
fontsize = 10;
colors = {[0 0 0] [0 0 1] [1 0 0] [.5 0 .5]}; 
type_line = {'-','--','-','-'};
type_mark = {'.','.','o','^'};
type_leg = {'-','--','-o','-^'};
nticks = 8;

if strcmp(modstr,'bb')
    axes = [0 2 -.2 .2;
            0 2 -.2 .2;
            0 2 -.2 .2;
            0 2 -.1 -0.02;
            0 2 0 .3;
            0 2 -1 -.199];
    impactfig1 = impact;
elseif strcmp(modstr,'drt')
    axes = [0 2 0 8/10000;
            0 2 -.15/100 .05/100;
            0 2 0 6/1000;
            0 2 -.1 -0.02;
            0 2 0 .3;
            0 2 -1 -.199];
    iphip = find(phips == phip_bb);
    iphik = find(phiks == phik_bb);
    isigma = find(sigmas == sigma_bb);
    impactfig1 = squeeze(impact(:,iphip,iphik,isigma,:));
end

titlestrs = {'SV Shock','SV Shock','SV Shock','Level Shock','Level Shock','Level Shock'};
reorder = [4,5,6,1,2,3];

if strcmp(modstr,'bb')
    figure(1);
    set(gcf,'Position',figbox);
    for j = 1:6
        % Set subplot and dimensions
        [col,row] = ind2sub(plotdim([2 1]),reorder(j));
        ivar = row; ishock = col;
        width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
        height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
        left = pad.leftmarg + (col-1)*(width+pad.hspace);
        bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
        subplot(plotdim(1),plotdim(2),reorder(j),'Position',[left bottom width height]); grid on; hold on; box on;

        % Plot
        if strcmp(modstr,'bb')
            plot(iess(iess<1),impactfig1(iess<1,j),'b')
            plot(iess(iess>1),impactfig1(iess>1,j),'b')
            plot([1,1],axes(j,3:4),'k--')
        elseif strcmp(modstr,'drt')
            plot(iess,impactfig1(:,j),'b')
        end
        plot(0.95,impactfig1(iess==0.95,j),'.r','MarkerSize',15)
        xlabel('IES ($\psi$)','fontsize',fontsize)
        ylabel([names1{j} ' ($\%$)'],'fontsize',fontsize)
        title(titlestrs{j},'fontsize',fontsize);
        axis(axes(j,:))
        set(gca,'xtick',0:.5:2)
    end

    if strcmp(saving,'on')
        savename = ['DRT Figures/fig_' modstr '_pref'];
        print(gcf,'-depsc2','-painters',[savename '.eps'])
        saveas(gcf,[savename '.fig'])
    end
end

if strcmp(modstr,'drt')
    figbox = [1 1.5 6.5 2.6];
    plotdim = [1,3];
    pad.topmarg = .2;
    pad.leftmarg = .075;
    pad.vspace = .175;
    pad.hspace = .09;
    pad.rightmarg = .02;
    pad.botmarg = .2;
    legadjust = [0,5,0,0];

    % Alternative price adjustment costs
    axes = [0 2 -2/10000 16/10000;
            0 2 -.15/100 .01/100;
            0 2 -.5/1000 10/1000;];
    %   Plot
    iphik = find(phiks == phik_bb);
    isigma = find(sigmas == sigma_bb);
    figure(2);
    set(gcf,'Position',figbox);
    for j = 1:3
        % Set subplot and dimensions
        [col,row] = ind2sub(plotdim([2 1]),j);
        ivar = row; ishock = col;
        width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
        height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
        left = pad.leftmarg + (col-1)*(width+pad.hspace);
        bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
        subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;

        % Plot
        p1 = zeros(nphip,1);
        for iphip = 1:nphip
            temp = impact(:,iphip,iphik,isigma,j);
            plot(iess,temp,type_line{iphip},'color',colors{iphip});
            if ~strcmp(type_mark{iphip},'.')
                plot(markergrid,interp1(iess,temp,markergrid,'pchip'),...
                    type_mark{iphip},'color',colors{iphip},'MarkerSize',markersize);  
            end
            p1(iphip) = plot(iess(1),temp(1),type_leg{iphip},'color',colors{iphip},'MarkerSize',markersize); 
        end
        xlabel('IES ($\psi$)','fontsize',fontsize)
        ylabel([names1{j} ' ($\%$)'],'fontsize',fontsize)
        axis(axes(j,:))
        set(gca,'xtick',0:.5:2)
    end
    %   Add Legend
    legstr = {};
    for iphip = 1:nphip
        legstr{iphip} = ['$\phi_P = ' num2str(round(100*phips(iphip))/100) '$'];
    end
    leg1 = legend(p1,legstr,'Orientation','horizontal',...
                            'Position',[.25 1-pad.topmarg+.05 0.5 pad.topmarg],...
                            'FontSize',fontsize,'interpreter','latex');

    if strcmp(saving,'on')
        savename = ['DRT Figures/fig_' modstr '_phip'];
        print(gcf,'-depsc2','-painters',[savename '.eps'])
        saveas(gcf,[savename '.fig'])
    end

    % Alternative capital adjustment costs
    axes = [0 2 -6/10000 8/10000;
            0 2 -.15/100 .02/100;
            0 2 -1/1000 8/1000];
    %   Plot
    iphip = find(phips == phip_bb);
    isigma = find(sigmas == sigma_bb);
    figure(3);
    set(gcf,'Position',figbox + [0,-1.5,0,0]);
    for j = 1:3
        % Set subplot and dimensions
        [col,row] = ind2sub(plotdim([2 1]),j);
        ivar = row; ishock = col;
        width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
        height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
        left = pad.leftmarg + (col-1)*(width+pad.hspace);
        bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
        subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;

        % Plot
        p1 = zeros(nphik,1);
        for iphik = 1:nphik
            temp = impact(:,iphip,iphik,isigma,j);
            plot(iess,temp,type_line{iphik},'color',colors{iphik});
            if ~strcmp(type_mark{iphik},'.')
                plot(markergrid,interp1(iess,temp,markergrid,'pchip'),...
                    type_mark{iphik},'color',colors{iphik},'MarkerSize',markersize);  
            end
            p1(iphik) = plot(iess(1),temp(1),type_leg{iphik},'color',colors{iphik},'MarkerSize',markersize); 
        end
        xlabel('IES ($\psi$)','fontsize',fontsize)
        ylabel([names1{j} ' ($\%$)'],'fontsize',fontsize)
        axis(axes(j,:))
        set(gca,'xtick',0:.5:2)
    end
    %   Add Legend
    legstr = {};
    for iphik = 1:nphik
        legstr{iphik} = ['$\phi_K = ' num2str(round(100*phiks(iphik))/100) '$'];
    end
    leg1 = legend(p1,legstr,'Orientation','horizontal',...
                            'Position',[.25 1-pad.topmarg+.05 0.5 pad.topmarg],...
                            'FontSize',fontsize,'interpreter','latex');

    if strcmp(saving,'on')
        savename = ['DRT Figures/fig_' modstr '_phik'];
        print(gcf,'-depsc2','-painters',[savename '.eps'])
        saveas(gcf,[savename '.fig'])
    end

    % Alternative risk aversions
    axes = [0 2 -20/10000 10/10000;
            0 2 -.30/100 .05/100;
            0 2 0 6/1000];
    iphip = find(phips == phip_bb);
    iphik = find(phiks == phik_bb);
    figure(4);
    set(gcf,'Position',figbox + [0,-3,0,0]);
    for j = 1:3
        % Set subplot and dimensions
        [col,row] = ind2sub(plotdim([2 1]),j);
        ivar = row; ishock = col;
        width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
        height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
        left = pad.leftmarg + (col-1)*(width+pad.hspace);
        bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
        subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;

        % Plot
        p1 = zeros(nsigma,1);
        for isigma = 1:nsigma
            temp = impact(:,iphip,iphik,isigma,j);
            plot(iess,temp,type_line{isigma},'color',colors{isigma});
            if ~strcmp(type_mark{isigma},'.')
                plot(markergrid,interp1(iess,temp,markergrid,'pchip'),...
                    type_mark{isigma},'color',colors{isigma},'MarkerSize',markersize);  
            end
            p1(isigma) = plot(iess(1),temp(1),type_leg{isigma},'color',colors{isigma},'MarkerSize',markersize); 
        end
        xlabel('IES ($\psi$)','fontsize',fontsize)
        ylabel([names1{j} ' ($\%$)'],'fontsize',fontsize)
        axis(axes(j,:))
        set(gca,'xtick',0:.5:2)
    end
    %   Add Legend
    legstr = {};
    for isigma = 1:nsigma
        legstr{isigma} = ['$\sigma = ' num2str(sigmas(isigma)) '$'];
    end
    leg1 = legend(p1,legstr,'Orientation','horizontal',...
                            'Position',[.25 1-pad.topmarg+.05 0.5 pad.topmarg],...
                            'FontSize',fontsize,'interpreter','latex');
    
    if strcmp(saving,'on')
        savename = ['DRT Figures/fig_' modstr '_sigma'];
        print(gcf,'-depsc2','-painters',[savename '.eps'])
        saveas(gcf,[savename '.fig'])
    end
end