clear; close all; clc

figonly = 0;

% figure: 
%   6(a): bb 
%   6(b): drt
modstr = 'bb';

% BB calibration
ies_bb = 0.95;

% Alternative Calibrations
volasss = [1,2,10]*0.0026251;
iess = sort([   linspace(.01,.75,10),...
                linspace(.76,.90,10),...
                linspace(.91,.9994,15),...
                linspace(1.0005,1.09,15),...
                linspace(1.10,1.5,10),...
                linspace(1.51,2,10),...
                ies_bb]);
nvolasss = numel(volasss);
nies = numel(iess);

if ~figonly
    addpath('C:\dynare\4.4.3\matlab')
    file_loc = cd;

    cd('BaselineModel\StickyvsFlexiblePrices')
    
    % Dynare pre-processor to generate m-file
    volass_m = 0.0026251;
    ies_m = ies_bb;
    save('param.mat','volass_m','ies_m')
    if strcmp(modstr,'bb')
        delete bbeffectivedemand_volass.m
        dynare bbeffectivedemand_volass.mod noclearall
    elseif strcmp(modstr,'drt')
        delete DRT_bbeffectivedemand_volass.m
        dynare DRT_bbeffectivedemand_volass.mod noclearall
    end

    y_impact_avol = zeros(nies,nvolasss);
    c_impact_avol = zeros(nies,nvolasss);
    i_impact_avol = zeros(nies,nvolasss);
    y_impact_alev = zeros(nies,nvolasss);
    c_impact_alev = zeros(nies,nvolasss);
    i_impact_alev = zeros(nies,nvolasss);

    % Alternative volatilities
    for ivolass = 1:nvolasss
        volass_m = volasss(ivolass);
        for iies = 1:nies
            ies_m = iess(iies);

            save('param.mat','volass_m','ies_m')
            if strcmp(modstr,'bb')
                bbeffectivedemand_volass;
            elseif strcmp(modstr,'drt')
                DRT_bbeffectivedemand_volass;
            end

            y_impact_avol(iies,ivolass) = 100*y_evola(1)./y_sss;
            c_impact_avol(iies,ivolass) = 100*c_evola(1)./c_sss;  
            i_impact_avol(iies,ivolass) = 100*inv_evola(1)./inv_sss;  
            y_impact_alev(iies,ivolass) = 100*y_ea(1)./y_sss;
            c_impact_alev(iies,ivolass) = 100*c_ea(1)./c_sss;  
            i_impact_alev(iies,ivolass) = 100*inv_ea(1)./inv_sss;
        end
    end
    
    cd(file_loc);
    
    if strcmp(modstr,'bb')
        impact = cat(3,y_impact_avol,c_impact_avol,i_impact_avol,y_impact_alev,c_impact_alev,i_impact_alev);
    elseif strcmp(modstr,'drt')
        impact = cat(3,y_impact_avol,c_impact_avol,i_impact_avol,-y_impact_alev,-c_impact_alev,-i_impact_alev);
    end
    
    names1 = {'Output','Consumption','Investment','Output','Consumption','Investment'};
    names2 = {'Volatility','Volatility','Volatility','Level','Level','Level'};
    names3 = {'Discount','Discount','Discount','Discount','Discount','Discount'};

    save(['temp_' modstr '_volass.mat'])
else
    load(['temp_' modstr '_volass.mat'])
end

%% Plot figures

saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
if strcmp(modstr,'bb')
    figbox = [1 4.5 6.5 2.3];
    pad.topmarg = .18;
    legadj = [0,0,0,-.05];
elseif strcmp(modstr,'drt')
    figbox = [1 4.5 6.5 2];
    pad.topmarg = .1;
    legadj = [0,0,0,-.02];
end
plotdim = [1,3];
pad.leftmarg = .075;
pad.vspace = .175;
pad.hspace = .09;
pad.rightmarg = .02;
pad.botmarg = .2;
markersize = 3;
markergrid = linspace(min(iess),max(iess),13);
fontsize = 10;
colors = {[0 0 0] [0 0 1] [1 0 0] [.5 0 .5]}; 
type_line = {'-','--','--','--'};
type_mark = {'.','.','o','^'};
type_leg = {'-','--','--o','--^'};
nticks = 4;


% Alternative price adjustment costs
if strcmp(modstr,'bb')
    axes = [0 2 -.2 .2;
            0 2 -.2 .2;
            0 2 -.2 .2];
elseif strcmp(modstr,'drt')
    axes = [0 2 0 .007;
            0 2 -.015 .001;
            0 2 0 .06];
end
%   Plot
figure(1);
set(gcf,'Position',figbox);
for j = 1:3
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),j);
    ivar = row; ishock = col;
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;

    % Plot
    p1 = zeros(nvolasss,1);
    for ivolass = 1:nvolasss
        temp = impact(:,ivolass,j);
        if strcmp(modstr,'bb')  
            idx = (iess' < 1 & temp < 0) | iess' < .5;
            plot(iess(idx),temp(idx),type_line{ivolass},'color',colors{ivolass});
            idx = iess' > 1 & temp > 0;
            plot(iess(idx),temp(idx),type_line{ivolass},'color',colors{ivolass});
        elseif strcmp(modstr,'drt')
            plot(iess,temp,type_line{ivolass},'color',colors{ivolass});
        end
        if ~strcmp(type_mark{ivolass},'.')
            plot(markergrid,interp1(iess,temp,markergrid,'pchip'),...
                type_mark{ivolass},'color',colors{ivolass},'MarkerSize',markersize);  
        end
        p1(ivolass) = plot(iess(1),temp(1),type_leg{ivolass},'color',colors{ivolass},'MarkerSize',markersize); 
    end
    xlabel('IES ($\psi$)','fontsize',fontsize)
    ylabel([names1{j} ' ($\%$)'],'fontsize',fontsize)
    axis(axes(j,:))
    if strcmp(modstr,'bb')
        plot([1,1],axes(j,[3,4]),'k--')
    end
    set(gca,'xtick',0:.5:2)
end

if strcmp(modstr,'bb')
    %   Add Legend
    legstr = {};
    for ivolass = 1:nvolasss
        legstr{ivolass} = ['$\sigma_a = ' num2str(round(1e4*volasss(ivolass))/1e4) '$'];
    end
    leg1 = legend(p1,legstr,'Orientation','horizontal',...
        'Position',[.25 1-pad.topmarg+.05 0.5 pad.topmarg] + legadj,...
        'FontSize',fontsize,'interpreter','latex');
end

if strcmp(saving,'on')
    savename = ['DRT Figures/fig_' modstr '_volass'];
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end