clear; close all; clc

figonly = 0;

% model: bb or drt
modstr = 'drt_disaster';

% BB calibration
ies_bb = 0.95;
ies_drt = 0.05;

% Alternative Calibrations
iess = sort([linspace(.01,.25,50),linspace(.3,2,10),ies_drt]);
nies = numel(iess);

if ~figonly
    addpath('C:\dynare\4.4.3\matlab')
    file_loc = cd;

    cd('BaselineModel/StickyvsFlexiblePrices')
    
    % Dynare pre-processor to generate m-file
    ies_m = ies_bb;
    save('ies.mat','ies_m')
    delete DRT_bbeffectivedemand_disaster_r3.m
    dynare DRT_bbeffectivedemand_disaster_r3.mod noclearall

    y_impact_avol = zeros(nies,1);
    c_impact_avol = zeros(nies,1);
    i_impact_avol = zeros(nies,1);
    y_impact_alev = zeros(nies,1);
    c_impact_alev = zeros(nies,1);
    i_impact_alev = zeros(nies,1);
    for iies = 1:nies
        ies_m = iess(iies);

        save('ies.mat','ies_m')
        DRT_bbeffectivedemand_disaster_r3;

        y_impact_avol(iies) = 100*y_evola(1)./y_sss;
        c_impact_avol(iies) = 100*c_evola(1)./c_sss;  
        i_impact_avol(iies) = 100*inv_evola(1)./inv_sss;  
        y_impact_alev(iies) = 100*y_ea(1)./y_sss;
        c_impact_alev(iies) = 100*c_ea(1)./c_sss;  
        i_impact_alev(iies) = 100*inv_ea(1)./inv_sss;
    end
    
    cd(file_loc);
    
    impact = [y_impact_avol,c_impact_avol,i_impact_avol,y_impact_alev,c_impact_alev,i_impact_alev];

    names1 = {'Output','Consumption','Investment','Output','Consumption','Investment'};
    names2 = {'Volatility','Volatility','Volatility','Level','Level','Level'};
    names3 = {'Discount','Discount','Discount','Discount','Discount','Discount'};

    save(['temp_' modstr '.mat'])
else
    load(['temp_' modstr '.mat'])
end

%% Plot figures

saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 2];
plotdim = [1,3];
pad.topmarg = .1;
pad.leftmarg = .06;
pad.vspace = .18;
pad.hspace = .06;
pad.rightmarg = .02;
pad.botmarg = .20;
markersize = 3;
markergrid = linspace(min(iess),max(iess),9);
fontsize = 10;
colors = {[0 0 0] [0 0 1] [1 0 0] [.5 0 .5]}; 
type_line = {'-','--','-','-'};
type_mark = {'.','.','o','^'};
type_leg = {'-','--','-o','-^'};
nticks = 8;

axes = [0 2 -.2 .015;
        0 2 -.2 .015;
        0 2 -.2 .015;
        0 2 -.05 1;
        0 2 -1 .05;
        0 2 -.05 1.5];

titlestrs = {'SV Shock','SV Shock','SV Shock','Level Shock','Level Shock','Level Shock'};

figure(1);
set(gcf,'Position',figbox);
for j = 1:3
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),j);
    ivar = row; ishock = col;
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;
    
    % Plot
    plot(iess,impact(:,j),'b')
    plot(ies_drt,impact(iess==ies_drt,j),'.r','MarkerSize',15)
    xlabel('IES ($\psi$)','fontsize',fontsize)
    title([names1{j} ' ($\%$)'],'fontsize',fontsize)
    axis(axes(j,:))
end

if strcmp(saving,'on')
    savename = ['DRT Figures/fig_' modstr];
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end