clear; close all; clc

figonly = 0;

if ~figonly
    addpath('C:\dynare\4.4.3\matlab')
    file_loc = cd;

    cd('BaselineModel/StickyvsFlexiblePrices')

    % BB calibration
    phip_m = 100;
    phik_m = 2.0901;
    sigma_m = 80;
    ies_m = 0.95;
    
    % Dynare pre-processor to generate m-file
    %   BB
    save('ies.mat','ies_m')
    delete bbeffectivedemand.m
    dynare bbeffectivedemand.mod noclearall
    %   DRT
    save('param.mat','phip_m','phik_m','sigma_m','ies_m')
    delete DRT_bbeffectivedemand.m
    dynare DRT_bbeffectivedemand.mod noclearall
    %   BB IRF
    save('ies.mat','ies_m')
    bbeffectivedemand;
    irf(:,1,1) = 100*y_ea./y_sss;
    irf(:,1,2) = 100*c_ea./c_sss;  
    irf(:,1,3) = 100*inv_ea./inv_sss;
    irf(:,1,4) = 100*y_evola./y_sss;
    irf(:,1,5) = 100*c_evola./c_sss;  
    irf(:,1,6) = 100*inv_evola./inv_sss;
    %   DRT IRF
    DRT_bbeffectivedemand;
    irf(:,2,1) = -100*y_ea./y_sss;
    irf(:,2,2) = -100*c_ea./c_sss;  
    irf(:,2,3) = -100*inv_ea./inv_sss;
    irf(:,2,4) = 100*y_evola./y_sss;
    irf(:,2,5) = 100*c_evola./c_sss;  
    irf(:,2,6) = 100*inv_evola./inv_sss;
    
    cd(file_loc);
    save('temp_irfcomp.mat')
else
    load('temp_irfcomp.mat')
end

%% Plot figures

saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 3.875];
plotdim = [2,3];
pad.topmarg = .14;
pad.leftmarg = .1;
pad.vspace = .18;
pad.hspace = .1;
pad.rightmarg = .02;
pad.botmarg = .12;
markersize = 15; 
fontsize = 10;
linetypes = {'k-','b--','r-.'};
axes = [0 20 -.15 0.001;
        0 20 0 .2;
        0 20 -.9 0.001;
        0 20 -.2 0.01;
        0 20 -.15 0.01;
        0 20 -.5 0.02];
    
varstrs = {'Output','Consumption','Investment','Output','Consumption','Investment'};
titlestrs = {'Level Shock','Level Shock','Level Shock','SV Shock','SV Shock','SV Shock'};

figure(1);
set(gcf,'Position',figbox);
for j = 1:6
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),j);
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;
    
    % Plot
    p1 = zeros(2,1);
    for imod = 1:2
        p1(imod) = plot(0:20,irf(:,imod,j),linetypes{imod});
    end
    ylabel([varstrs{j} ' ($\%$)'],'fontsize',fontsize)
    xlabel('Quarters','fontsize',fontsize)
    title(titlestrs{j},'fontsize',fontsize);
    axis(axes(j,:))
    set(gca,'xtick',0:4:20)
end
%   Add Legend
legstr = {'BB Preferences','Alternative Preferences'};
leg1 = legend(p1,legstr,'Orientation','horizontal',...
                        'Position',[.25 1-pad.topmarg+.03 0.5 pad.topmarg],...
                        'FontSize',fontsize,'interpreter','latex');

if strcmp(saving,'on')
    savename = 'DRT Figures/fig_irfcomp';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end