clear; close all; clc

volvolas = [0.0025022,0.0025022/6];

addpath('C:\dynare\4.4.3\matlab')
file_loc = cd;

cd('BaselineModel/StickyvsFlexiblePrices')

% BB parameterization
ies_m = 0.95;
volvola_m = 0.0025022;
save('param.mat','ies_m','volvola_m')

% Dynare pre-processor to generate m-file
delete DRT_bbeffectivedemand_riskprem.m
dynare DRT_bbeffectivedemand_riskprem.mod noclearall

for ivolvola = 1:numel(volvolas)
    % Parameters
    volvola_m = volvolas(ivolvola);
    save('param.mat','ies_m','volvola_m')
    % IRF
    DRT_bbeffectivedemand_riskprem;
    vxo_evola = sqrt(4*(max(varexpre_evola+varexpre_sss,1e-16)));
    vxo_sss = sqrt(4*(varexpre_sss));
    irf(:,ivolvola,1) = 100*vola_evola./vola_sss;
    irf(:,ivolvola,2) = 100*log(vxo_evola./ vxo_sss);
    irf(:,ivolvola,3) = 100*y_evola./y_sss;
end

cd(file_loc);

load('VAREvidence/Quarterly/Baseline/irfdata.mat')
vxo_vxodata = 100*IRpoint(:,1,1);
y_vxodata = 100*IRpoint(:,2,1);

irf(1:20,3,2) = vxo_vxodata;
irf(1:20,3,3) = y_vxodata;


%% Plot figures

saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 2.25];
plotdim = [1,3];
pad.topmarg = .25;
pad.leftmarg = .05;
pad.vspace = .18;
pad.hspace = .06;
pad.rightmarg = .02;
pad.botmarg = .175;
markersize = 15; 
fontsize = 10;
linetypes = {'k-','b--','r-.'};
axes = [0 20 -.15 0;
        0 20 0 .2;
        0 20 -.9 0;
        0 20 -.2 0.01;
        0 20 -.15 0.01;
        0 20 -.5 0.01];
    
varstrs = {'Shock Volatility','Stock Market Volatility','Output'};

figure(1);
set(gcf,'Position',figbox);
p1 = zeros(3,3);
for j = 1:3
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),j);
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;
    
    % Plot
    for imod = 1:3
        if imod < 3
            p1(j,imod) = plot(0:20,irf(:,imod,j),linetypes{imod});
        else
            p1(j,imod) = plot(0:19,irf(1:20,imod,j),linetypes{imod});
        end
    end
    title([varstrs{j} ' ($\%$)'],'fontsize',fontsize)
    xlabel('Quarters','fontsize',fontsize)
    set(gca,'xtick',0:4:20)
end
%   Add Legend
legstr = {['$\sigma^{\sigma^{rp}} = ' num2str(round(volvolas(1)*1e4)/1e4) '$'],...
          ['$\sigma^{\sigma^{rp}} = ' num2str(round(volvolas(2)*1e4)/1e4) '$'],...
          'Data - Estimated Response'};
leg1 = legend(p1(3,:),legstr,'Orientation','horizontal',...
                        'Position',[.25 1-pad.topmarg+.06 0.5 pad.topmarg],...
                        'FontSize',fontsize,'interpreter','latex');
delete(p1(1,3))
if strcmp(saving,'on')
    savename = 'DRT Figures/fig_irfcomp_riskprem';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end