clear; close all; clc

saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 2];
plotdim = [1,3];
pad.topmarg = .25;
pad.leftmarg = .1;
pad.vspace = .175;
pad.hspace = .125;
pad.rightmarg = .02;
pad.botmarg = .20;
fontsize = 10;

%   Preference volatility shock
linetypes = {'k-','b--','r-.'};
legstrs = {'BB Preferences','Alternative Preferences','Additively Separable Preferences'};
modstrs = {'bb_pref','drt_pref','bb_pref_as'};
nmods = numel(modstrs);
for imod = 1:nmods
    load(['temp_' modstrs{imod} '_expu.mat'])
    impacts{imod} = impact;
    iesss{imod} = iess;
end

figure(1);
set(gcf,'Position',figbox);
for j = 1:3
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),j);
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;
    
    % Plot
    for imod = 1:nmods
        temp = impacts{imod};
        p1(j,imod) = plot(iesss{imod},temp(:,j),linetypes{imod});
    end
    xlabel('IES ($\psi$)','fontsize',fontsize)
    ylabel([names1{j} ' ($\%$)'],'fontsize',fontsize)
    set(gca,'xtick',0:.5:2)
end
%   Add Legend
leg1 = legend(p1(3,:),legstrs,'Orientation','horizontal',...
    'Position',[.25 1-pad.topmarg+.04 0.5 pad.topmarg],...
    'FontSize',fontsize,'interpreter','latex');

if strcmp(saving,'on')
    savename = 'DRT Figures/fig_pref_expu';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end

%   Risk premium volatility shock
linetypes = {'k-','r-.'};
legstrs = {'BB/Alternative Preferences','Additively Separable Preferences'};
modstrs = {'drt_riskprem','bb_riskprem_as'};
nmods = numel(modstrs);
for imod = 1:nmods
    load(['temp_' modstrs{imod} '_expu.mat'])
    impacts{imod} = impact;
    iesss{imod} = iess;
end

figure(2);
set(gcf,'Position',figbox);
for j = 1:3
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),j);
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;
    
    % Plot
    for imod = 1:nmods
        temp = impacts{imod};
        p1(j,imod) = plot(iesss{imod},temp(:,j),linetypes{imod});
    end
    xlabel('IES ($\psi$)','fontsize',fontsize)
    ylabel([names1{j} ' ($\%$)'],'fontsize',fontsize)
    set(gca,'xtick',0:.5:2)
end
%   Add Legend
leg1 = legend(p1(3,:)',legstrs,'Orientation','horizontal',...
    'Position',[.25 1-pad.topmarg+.04 0.5 pad.topmarg],...
    'FontSize',fontsize,'interpreter','latex');

if strcmp(saving,'on')
    savename = 'DRT Figures/fig_riskprem_expu';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end