clear; close all; clc

modstrs = {...
    'bb_pref','drt_pref','bb_pref_as',...
    'drt_riskprem','bb_riskprem_as'};
    
% BB calibration
ies_bb = 0.95;

% Alternative Calibrations
iess = sort([   linspace(.01,.5,5),...
                linspace(.6,.75,5),...
                linspace(.76,.90,10),...
                linspace(.91,.9994,15),...
                linspace(1.0005,1.09,15),...
                linspace(1.10,1.5,10),...
                linspace(1.51,2,10),...
                ies_bb]);
nies = numel(iess);

addpath('C:\dynare\4.4.3\matlab')
file_loc = cd;

for imod = 1:numel(modstrs)
    modstr = modstrs{imod};
    cd('BaselineModel/StickyvsFlexiblePrices')
    % Dynare pre-processor to generate m-file
    ies_m = ies_bb;
    save('ies.mat','ies_m')
    if strcmp(modstr,'bb_pref')
        delete bbeffectivedemand_expu.m
        dynare bbeffectivedemand_expu.mod noclearall
    elseif strcmp(modstr,'bb_pref_2015')
        delete bbeffectivedemand_2015_expu.m
        dynare bbeffectivedemand_2015_expu.mod noclearall
    elseif strcmp(modstr,'drt_pref')
        delete DRT_bbeffectivedemand_expu.m
        dynare DRT_bbeffectivedemand_expu.mod noclearall
    elseif strcmp(modstr,'drt_riskprem')
        delete DRT_bbeffectivedemand_riskprem_expu.m
        dynare DRT_bbeffectivedemand_riskprem_expu.mod noclearall
    elseif strcmp(modstr,'bb_pref_as')
        delete bbeffectivedemand_expu_as.m
        dynare bbeffectivedemand_expu_as.mod noclearall
    elseif strcmp(modstr,'bb_riskprem_as')
        delete bbeffectivedemand_riskprem_expu_as.m
        dynare bbeffectivedemand_riskprem_expu_as.mod noclearall
    elseif strcmp(modstr,'bb_pref_as_habit')
        delete bbeffectivedemand_expu_as_habit.m
        dynare bbeffectivedemand_expu_as_habit.mod noclearall
    end

    y_impact_avol = zeros(nies,1);
    c_impact_avol = zeros(nies,1);
    i_impact_avol = zeros(nies,1);
    y_impact_alev = zeros(nies,1);
    c_impact_alev = zeros(nies,1);
    i_impact_alev = zeros(nies,1);
    for iies = 1:nies
        ies_m = iess(iies);

        save('ies.mat','ies_m')
        if strcmp(modstr,'bb_pref')
            bbeffectivedemand_expu;
        elseif strcmp(modstr,'bb_pref_2015')
            bbeffectivedemand_2015_expu;
        elseif strcmp(modstr,'drt_pref')
            DRT_bbeffectivedemand_expu;
        elseif strcmp(modstr,'drt_riskprem')
            DRT_bbeffectivedemand_riskprem_expu;
        elseif strcmp(modstr,'bb_pref_as')
            bbeffectivedemand_expu_as;
        elseif strcmp(modstr,'bb_riskprem_as')
            bbeffectivedemand_riskprem_expu_as;
        elseif strcmp(modstr,'bb_pref_as_habit')
            bbeffectivedemand_expu_as_habit;
        end

        y_impact_avol(iies) = 100*y_evola(1)./y_sss;
        c_impact_avol(iies) = 100*c_evola(1)./c_sss;  
        i_impact_avol(iies) = 100*inv_evola(1)./inv_sss;  
    end

    cd(file_loc);

    impact = [y_impact_avol,c_impact_avol,i_impact_avol];

    names1 = {'Output','Consumption','Investment','Output','Consumption','Investment'};
    names2 = {'Volatility','Volatility','Volatility','Level','Level','Level'};
    names3 = {'Discount','Discount','Discount','Discount','Discount','Discount'};

    save(['temp_' modstr '_expu.mat'])
end