clear; close all; clc

figonly = 0;

% BB calibration
frischlse_bb = 2;
rhor_bb = 0;
ies_bb = 0.95;

% Alternative Calibrations
frischlses = [.5,2,4,8];
rhors = [0,.2,.4,.8];
iess = sort([   linspace(.01,.75,10),...
                linspace(.76,.90,10),...
                linspace(.91,.9994,15),...
                linspace(1.0005,1.09,15),...
                linspace(1.10,1.5,10),...
                linspace(1.51,2,10),...
                .95]);
nfrischlse = numel(frischlses);
nrhor = numel(rhors);
nies = numel(iess);

if ~figonly
    addpath('C:\dynare\4.4.3\matlab')
    file_loc = cd;

    cd('BaselineModel/StickyvsFlexiblePrices')
    
    % Dynare pre-processor to generate m-file
    frischlse_m = frischlse_bb;
    rhor_m = rhor_bb;
    ies_m = ies_bb;

    save('param.mat','frischlse_m','rhor_m','ies_m')
    delete DRT_bbeffectivedemand_appendix.m
    dynare DRT_bbeffectivedemand_appendix.mod noclearall

    y_impact_vol = zeros(nies,nfrischlse,nrhor);
    c_impact_vol = zeros(nies,nfrischlse,nrhor);
    i_impact_vol = zeros(nies,nfrischlse,nrhor);
    y_impact_lev = zeros(nies,nfrischlse,nrhor);
    c_impact_lev = zeros(nies,nfrischlse,nrhor);
    i_impact_lev = zeros(nies,nfrischlse,nrhor);

    % Alternative price adjustment costs
    irhor = find(rhors == rhor_bb);
    for ifrischlse = 1:nfrischlse
        for iies = 1:nies
            frischlse_m = frischlses(ifrischlse);
            rhor_m = rhors(irhor);
            ies_m = iess(iies);

            save('param.mat','frischlse_m','rhor_m','ies_m')
            DRT_bbeffectivedemand_appendix;

            y_impact_vol(iies,ifrischlse,irhor) = 100*y_evola(1)./y_sss;
            c_impact_vol(iies,ifrischlse,irhor) = 100*c_evola(1)./c_sss;  
            i_impact_vol(iies,ifrischlse,irhor) = 100*inv_evola(1)./inv_sss;  
            y_impact_lev(iies,ifrischlse,irhor) = 100*y_ea(1)./y_sss;
            c_impact_lev(iies,ifrischlse,irhor) = 100*c_ea(1)./c_sss;  
            i_impact_lev(iies,ifrischlse,irhor) = 100*inv_ea(1)./inv_sss;
        end
    end

    % Alternative capital adjustment costs
    ifrischlse = find(frischlses == frischlse_bb);
    for irhor = setdiff(1:nrhor,find(rhors == rhor_bb))
        for iies = 1:nies
            frischlse_m = frischlses(ifrischlse);
            rhor_m = rhors(irhor);
            ies_m = iess(iies);

            save('param.mat','frischlse_m','rhor_m','ies_m')
            DRT_bbeffectivedemand_appendix;

            y_impact_vol(iies,ifrischlse,irhor) = 100*y_evola(1)./y_sss;
            c_impact_vol(iies,ifrischlse,irhor) = 100*c_evola(1)./c_sss;  
            i_impact_vol(iies,ifrischlse,irhor) = 100*inv_evola(1)./inv_sss;  
            y_impact_lev(iies,ifrischlse,irhor) = 100*y_ea(1)./y_sss;
            c_impact_lev(iies,ifrischlse,irhor) = 100*c_ea(1)./c_sss;  
            i_impact_lev(iies,ifrischlse,irhor) = 100*inv_ea(1)./inv_sss;  
        end
    end
    
    cd(file_loc);
    
    impact = cat(4,y_impact_vol,c_impact_vol,i_impact_vol,-y_impact_lev,-c_impact_lev,-i_impact_lev);
    
    names1 = {'Output','Consumption','Investment','Output','Consumption','Investment'};
    names2 = {'Volatility','Volatility','Volatility','Level','Level','Level'};
    names3 = {'Discount','Discount','Discount','Discount','Discount','Discount'};

    save('temp_drt_appendix.mat')
else
    load('temp_drt_appendix.mat')
end

%% Plot figures

saving = 'on';

set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
markersize = 3;
markergrid = linspace(min(iess),max(iess),9);
fontsize = 10;
colors = {[0 0 0] [0 0 1] [1 0 0] [.5 0 .5]}; 
type_line = {'-','--','--','--'};
type_mark = {'.','.','o','^'};
type_leg = {'-','--','--o','--^'};
nticks = 8;

figbox = [1 1.5 6.5 2.5];
plotdim = [1,3];
pad.topmarg = .2;
pad.leftmarg = .075;
pad.vspace = .175;
pad.hspace = .09;
pad.rightmarg = .02;
pad.botmarg = .2;
legadjust = [0,5,0,0];

% Alternative price adjustment costs
axes = [0 2 -2/10000 16/10000;
        0 2 -.15/100 .01/100;
        0 2 -.5/1000 10/1000;];
%   Plot
irhor = find(rhors == rhor_bb);
figure(2);
set(gcf,'Position',figbox);
lineorder = [1,2,3,4];
for j = 1:3
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),j);
    ivar = row; ishock = col;
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;

    % Plot
    p1 = zeros(nfrischlse,1);
    for ifrischlse = 1:nfrischlse
        temp = impact(:,ifrischlse,irhor,j);
        iline = lineorder(ifrischlse);
        plot(iess,temp,type_line{iline},'color',colors{iline});
        if ~strcmp(type_mark{iline},'.')
            plot(markergrid,interp1(iess,temp,markergrid,'pchip'),...
                type_mark{iline},'color',colors{iline},'MarkerSize',markersize);  
        end
        p1(ifrischlse) = plot(iess(1),temp(1),type_leg{iline},'color',colors{iline},'MarkerSize',markersize); 
    end
    xlabel('IES ($\psi$)','fontsize',fontsize)
    ylabel([names1{j} ' ($\%$)'],'fontsize',fontsize)
    axis(axes(j,:))
    set(gca,'xtick',0:.5:2)
end
%   Add Legend
legstr = {};
for ifrischlse = 1:nfrischlse
    legstr{ifrischlse} = ['$\varepsilon_n = ' num2str(round(100*frischlses(ifrischlse))/100) '$'];
end
leg1 = legend(p1,legstr,'Orientation','horizontal',...
    'Position',[.25 1-pad.topmarg+.05 0.5 pad.topmarg],...
    'FontSize',fontsize,'interpreter','latex');

if strcmp(saving,'on')
    savename = 'DRT Figures/fig_drt_frischlse';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end

% Alternative capital adjustment costs
axes = [0 2 2/10000 7/10000;
        0 2 -.15/100 .02/100;
        0 2 0 6/1000];
%   Plot
ifrischlse = find(frischlses == frischlse_bb);
figure(1);
set(gcf,'Position',figbox + [0,-1.5,0,0]);
lineorder = [2,1,3,4];
for j = 1:3
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),j);
    ivar = row; ishock = col;
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;

    % Plot
    p1 = zeros(nrhor,1);
    for irhor = 1:nrhor
        temp = impact(:,ifrischlse,irhor,j);
        iline = lineorder(irhor);
        plot(iess,temp,type_line{iline},'color',colors{iline});
        if ~strcmp(type_mark{iline},'.')
            plot(markergrid,interp1(iess,temp,markergrid,'pchip'),...
                type_mark{iline},'color',colors{iline},'MarkerSize',markersize);  
        end
        p1(irhor) = plot(iess(1),temp(1),type_leg{iline},'color',colors{iline},'MarkerSize',markersize); 
    end
    xlabel('IES ($\psi$)','fontsize',fontsize)
    ylabel([names1{j} ' ($\%$)'],'fontsize',fontsize)
    axis(axes(j,:))
    set(gca,'xtick',0:.5:2)
end
%   Add Legend
legstr = {};
for irhor = 1:nrhor
    legstr{irhor} = ['$\rho_r = ' num2str(round(100*rhors(irhor))/100) '$'];
end
leg1 = legend(p1,legstr,'Orientation','horizontal',...
    'Position',[.25 1-pad.topmarg+.05 0.5 pad.topmarg],...
    'FontSize',fontsize,'interpreter','latex');

if strcmp(saving,'on')
    savename = 'DRT Figures/fig_drt_rhor';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end