clear; close all; clc

figonly = 0;

% BB calibration
ies_bb = 0.95;

% Alternative Calibrations
iess = sort([   linspace(.01,.75,10),...
                linspace(.76,.90,10),...
                linspace(.91,.9999,15),...
                linspace(1.0001,1.09,15),...
                linspace(1.10,1.5,10),...
                linspace(1.51,2,10),...
                .95]);
nies = numel(iess);

if ~figonly
    addpath('C:\dynare\4.4.3\matlab')
    file_loc = cd;

    cd('BaselineModel/ModelFeatures/TechnologyUncertaintyShock&RealMUs')
    
    % Dynare pre-processor to generate m-file
    ies_m = ies_bb;
    save('ies.mat','ies_m')
    delete bbeffectivedemandtechnologyuncertainty.m
    dynare bbeffectivedemandtechnologyuncertainty.mod noclearall

    y_impact_zvol = zeros(nies,1);
    y_impact_zlev = zeros(nies,1);
    for iies = 1:nies
        ies_m = iess(iies);

        save('ies.mat','ies_m')
        bbeffectivedemandtechnologyuncertainty;

        y_impact_zvol(iies) = 100*y_evolz(1)./y_sss;
        y_impact_zlev(iies) = 100*y_ez(1)./y_sss;
    end  
    impactz(:,:,1) = [y_impact_zvol,y_impact_zlev];
    
    ies_m = ies_bb;
    save('ies.mat','ies_m')
    delete DRT_bbeffectivedemandtechnologyuncerta.m
    dynare DRT_bbeffectivedemandtechnologyuncerta.mod noclearall

    y_impact_zvol = zeros(nies,1);
    y_impact_zlev = zeros(nies,1);
    for iies = 1:nies
        ies_m = iess(iies);

        save('ies.mat','ies_m')
        DRT_bbeffectivedemandtechnologyuncerta;

        y_impact_zvol(iies) = 100*y_evolz(1)./y_sss;
        y_impact_zlev(iies) = 100*y_ez(1)./y_sss;
    end
    impactz(:,:,2) = [y_impact_zvol,y_impact_zlev];
    
    cd(file_loc);
    
    save('temp_techSV.mat')
else
    load('temp_techSV.mat','impactz','iess')
end

% Swap SV and level shocks
impactz = impactz(:,[2,1],:);

%% Plot figures
saving = 'on';
    
set(0,'DefaultAxesFontName','Times New Roman')
set(0,'DefaultFigureUnits','inches')
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultFigurePaperPositionMode','auto')
set(0,'DefaultLineLineWidth',1)
set(0,'DefaultTextInterpreter','Latex')
figbox = [1 4.5 6.5 2];
plotdim = [1,2];
pad.topmarg = .1;
pad.leftmarg = .1;
pad.vspace = .175;
pad.hspace = .1;
pad.rightmarg = .02;
pad.botmarg = .2;
fontsize = 10;
colors = {[0 0 0] [0 0 1] [1 0 0] [.5 0 .5]}; 
type_line = {'-','--','--','--'};
type_mark = {'.','.','o','^'};
type_leg = {'-','--','--o','--^'};
nticks = 8;

axes = [0 2 0 .125;
        0 2 -.0009 -.0007;
        0 2 0 .125;
        0 2 -.0009 -.0007];

ylabels = {'BB Preferences','Alternative Preferences'};
titlestrs = {'Level Shock','SV Shock'};

figure(1);
set(gcf,'Position',figbox);
for j = 1:2
    % Set subplot and dimensions
    [col,row] = ind2sub(plotdim([2 1]),j);
    imod = row; ishock = col;
    width = (1-pad.leftmarg-pad.hspace*(plotdim(2)-1)-pad.rightmarg)/plotdim(2);
    height = (1-pad.topmarg-pad.vspace*(plotdim(1)-1)-pad.botmarg)/plotdim(1);
    left = pad.leftmarg + (col-1)*(width+pad.hspace);
    bottom = 1-pad.topmarg-row*height-(row-1)*pad.vspace;
    subplot(plotdim(1),plotdim(2),j,'Position',[left bottom width height]); grid on; hold on; box on;

    % Plot
    temp = impactz(:,ishock,imod);
    if imod == 1
        plot(iess(iess<1),temp(iess<1),'b')
        plot(iess(iess>1),temp(iess>1),'b')
        plot([1,1],axes(j,3:4),'k--')
    elseif imod == 2
        plot(iess,temp(:),'b')
    end
    plot(0.95,temp(iess==0.95),'.r','MarkerSize',15)
    xlabel('IES ($\psi$)','fontsize',fontsize)
    ylabel(ylabels{imod},'fontsize',fontsize)
    title(titlestrs{ishock},'fontsize',fontsize);
    axis(axes(j,:))
    set(gca,'xtick',.5:.25:1.5,'xlim',[.5,1.5])
end

if strcmp(saving,'on')
    savename = 'DRT Figures/fig_tech';
    print(gcf,'-depsc2','-painters',[savename '.eps'])
    saveas(gcf,[savename '.fig'])
end